@@ -8,7 +8,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.boaccounts.inc.php,v 1.22.2.7.2.22 2004/11/06 16:13:47 powerstat Exp $ */
+	/* $Id: class.boaccounts.inc.php,v 1.22.2.7.2.23 2005/06/02 23:31:02 skwashd Exp $ */
 
 	class boaccounts
 	{
@@ -115,7 +115,7 @@
 
 			$GLOBALS['phpgw']->db->unlock();
 
-			Header('Location: '.$GLOBALS['phpgw']->link('/index.php','menuaction=admin.uiaccounts.list_groups'));
+			$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.uiaccounts.list_groups') );
 			$GLOBALS['phpgw']->common->phpgw_exit();
 		}
 
@@ -633,7 +633,7 @@
 		{
 			if($GLOBALS['phpgw']->acl->check('group_access',16,'admin') || $_POST['cancel'])
 			{
-				$GLOBALS['phpgw']->redirect($GLOBALS['phpgw']->link('/index.php','menuaction=admin.uiaccounts.list_groups'));
+				$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' => 'admin.uiaccounts.list_groups') );
 				$GLOBALS['phpgw']->common->phpgw_exit();
 			}
 			elseif($_POST['submit'])
@@ -653,7 +653,7 @@
 					$acl->add_repository('phpgw_group',intval($_POST['account_id']),$manager,(1 + PHPGW_ACL_GROUP_MANAGERS));
 				}
 			}
-			$GLOBALS['phpgw']->redirect($GLOBALS['phpgw']->link('/index.php','menuaction=admin.uiaccounts.list_groups'));
+			$GLOBALS['phpgw']->redirect_link('/index.php', array('menuaction' =>'admin.uiaccounts.list_groups') );
 			$GLOBALS['phpgw']->common->phpgw_exit();
 		}
 
