@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-	/* $Id: class.boicalendar.inc.php,v 1.16.2.4.2.6 2004/11/06 16:13:42 powerstat Exp $ */
+	/* $Id: class.boicalendar.inc.php,v 1.16.2.4.2.9 2005/12/08 12:17:24 skwashd Exp $ */
 
 define('FOLD_LENGTH',75);
 
@@ -806,6 +806,15 @@ class boicalendar
 					'contact'		=> True					
 				)
 			),
+			'freq'		=> Array( //this is here to be RFC 2445 compliant - skwashd Dec-2005
+				'type'		=> 'function',
+				'function'	=> 'switch_freq',
+				'quoted'		=> False,
+				'to_text'	=> False,
+				'properties'	=> Array(
+					'rrule'			=> True
+				)
+			),
 			'byday'		=> Array(
 				'type'		=> 'text',
 				'quoted'		=> False,
@@ -993,15 +1002,6 @@ class boicalendar
 					'attach'			=> True
 				)
 			),
-			'freq'		=> Array(
-				'type'		=> 'function',
-				'function'	=> 'switch_freq',
-				'quoted'		=> False,
-				'to_text'	=> False,
-				'properties'	=> Array(
-					'rrule'			=> True
-				)
-			),
 			'interval'		=> Array(
 				'type'		=> 'integer',
 				'quoted'		=> False,
@@ -1622,6 +1622,7 @@ class boicalendar
 					{
 						$value = $this->to_text($value);
 					}
+
 					switch($type)
 					{
 						case 'dir':
@@ -1633,6 +1634,9 @@ class boicalendar
 							$this->debug($key.' Function Param : '.$value);
 							$str .= $quote.$this->$function($value).$quote;
 							break;
+						case 'integer':
+							$str .= ';' . strtoupper($key) . "=$value";
+							break;
 						case 'text':
 						case 'string':
 							$str .= ';'.strtoupper($key).'='.$quote.$value.$quote;
@@ -3205,12 +3209,12 @@ class boicalendar
 //					$event = $so_event->get_cached_event();
 				}
 			}
-			Header('Location: '.$GLOBALS['phpgw']->link('/index.php',
-					Array(
-						'menuaction'	=> 'calendar.uicalendar.view',
-						'cal_id'	=> $event['id']
-					)
-				)
+			$GLOBALS['phpgw']->redirect_link('/index.php',
+							array
+							(
+								'menuaction'	=> 'calendar.uicalendar.view',
+								'cal_id'	=> $event['id']
+							)
 			);
 			$GLOBALS['phpgw']->common->phpgw_exit();
 		}
@@ -3222,9 +3226,9 @@ class boicalendar
 			$method = ($params['method']?$params['method']:"publish");
 
 			$string_array = Array(
-				'summary'		=> 'description',
-				'location'		=> 'location',
-				'description'	=> 'title',
+				'description'	=> 'description',
+				'location'	=> 'location',
+				'summary'	=> 'title',
 				'uid'		=> 'uid'
 			);
 
@@ -3285,6 +3289,7 @@ class boicalendar
 					}
 				}
 
+				/* The output from here is already GMT - so no TZ offset is reuquired - see RFC2445 - skwashd Dec2005
 				// use system's date info for caluculating local timezone's offset in minutes
 				//
 				$gmt_offset = date('O',$GLOBALS['phpgw']->datetime->users_localtime);  // offset to GMT
@@ -3295,6 +3300,7 @@ class boicalendar
 					$event['end']['min']     -= $offset;
 					$event['modtime']['min'] -= $offset;
 				}
+				*/
 
 				$ical_event['priority'] = $event['priority'];
 				$ical_event['class'] = intval($event['public']);
@@ -3428,11 +3434,10 @@ class boicalendar
 					}
 					$this->parse_value($ical_event,'rrule',$str,'vevent');
 
-					$exceptions = $event['recur_exception'];
+					$exceptions =& $event['recur_exception'];
 					if(is_array($exceptions))
 					{
-						@reset($exceptions);
-						while(list($key,$except_datetime) = each($exceptions))
+						foreach ( $exceptions as $key => $except_datetime )
 						{
 							$ical_event['exdate'][] = $this->switch_date(date('Ymd\THis\Z',$except_datetime));
 						}
