@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bofelamimail.inc.php,v 1.2.2.12.2.4 2004/01/20 05:33:28 jengo Exp $ */
+	/* $Id: class.bofelamimail.inc.php,v 1.2.2.12.2.5 2006/07/07 09:10:28 sigurdne Exp $ */
 
 	class bofelamimail
 	{
@@ -941,7 +941,7 @@
 				// get the quota for this mailboxbox
 				if (function_exists('imap_get_quotaroot'))
 				{
-					$quota = imap_get_quotaroot($this->mbox, $_folderName);
+					$quota = @imap_get_quotaroot($this->mbox, $_folderName);
 					if(is_array($quota['STORAGE'])) 
 					{
 						$storage = $this->storageQuota = $quota['STORAGE'];
@@ -1276,4 +1276,4 @@
 			}
 		}
 	}
-?>
\ No newline at end of file
+?>
