@@ -7,7 +7,7 @@
 	* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage application
-	* @version $Id: class.config.inc.php,v 1.7.2.1.2.6 2005/08/09 13:04:56 skwashd Exp $
+	* @version $Id: class.config.inc.php,v 1.7.2.1.2.7 2005/12/03 22:31:55 skwashd Exp $
 	*/
 
 	/**
@@ -39,7 +39,7 @@
 			while ($this->db->next_record())
 			{
 				$test = @unserialize($this->db->f('config_value', true));
-				if($test)
+				if ( $test !== false )
 				{
 					$this->config_data[$this->db->f('config_name')] = $test;
 				}
@@ -57,7 +57,7 @@
 				$config_data =& $this->config_data;
 				
 				$this->db->lock(array('phpgw_config', 'phpgw_app_sessions'));
-				//$this->db->query("DELETE FROM phpgw_config WHERE config_app = '{$this->appname}'",__LINE__,__FILE__); //someone removed this without a proper explanation!
+				$this->db->query("DELETE FROM phpgw_config WHERE config_app = '{$this->appname}'",__LINE__,__FILE__);
 				if($this->appname == 'phpgwapi')
 				{
 					$this->db->query('DELETE FROM phpgw_app_sessions'
