@@ -1,7 +1,7 @@
 <?php
 /**
  * HTML Sanitizer, attemtpts to make variables safe for users.
- * $Id: class.data_cleaner.inc.php,v 1.1.2.4 2005/09/30 16:22:28 Caeies Exp $
+ * $Id: class.data_cleaner.inc.php,v 1.1.2.5 2006/01/07 11:37:51 skwashd Exp $
  *
  * Taken from the horde project by Dave Hall for use in phpGroupWare
  *
@@ -117,7 +117,7 @@ class data_cleaner
 
 		/* Remove everything outside of and including the <body> tag
 		 * if displaying inline. */
-		if (!$attachment) {
+		if (!isset($attachment) || !$attachment) {
 			$data = preg_replace('/.*<body[^>]*>/si', '', $data);
 			$data = preg_replace('/<\/body>.*/si', '', $data);
 		}
