@@ -10,7 +10,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage accounts
-	* @version $Id: class.sessions.inc.php,v 1.104.4.24 2005/05/30 15:07:26 ceb Exp $
+	* @version $Id: class.sessions.inc.php,v 1.104.4.25 2005/12/07 10:50:53 skwashd Exp $
 	* @link http://www.sanisoft.com/phplib/manual/DB_sql.php
 	*/
 
@@ -629,22 +629,29 @@
 			$ip = $this->db->db_addslashes($ip);
 			$this->db->query("SELECT count(*) FROM phpgw_access_log WHERE account_id=0 AND ip='$ip' AND li > $block_time",__LINE__,__FILE__);
 			$this->db->next_record();
-			if (($false_ip = $this->db->f(0)) > $GLOBALS['phpgw_info']['server']['num_unsuccessful_ip'])
+			if (($false_ip = $this->db->f(0)) >= $GLOBALS['phpgw_info']['server']['num_unsuccessful_ip'])
 			{
 				//echo "<p>login_blocked: ip='$ip' ".$this->db->f(0)." tries (".$GLOBALS['phpgw_info']['server']['num_unsuccessful_ip']." max.) since ".date('Y/m/d H:i',$block_time)."</p>\n";
 				$blocked = True;
 			}
+
 			$login = $this->db->db_addslashes($login);
 			$this->db->query("SELECT count(*) FROM phpgw_access_log WHERE account_id=0 AND (loginid='$login' OR loginid LIKE '$login@%') AND li > $block_time",__LINE__,__FILE__);
 			$this->db->next_record();
-			if (($false_id = $this->db->f(0)) > $GLOBALS['phpgw_info']['server']['num_unsuccessful_id'])
+			if ( !$blocked && ($false_id = $this->db->f(0)) >= $GLOBALS['phpgw_info']['server']['num_unsuccessful_id'])
 			{
-				//echo "<p>login_blocked: login='$login' ".$this->db->f(0)." tries (".$GLOBALS['phpgw_info']['server']['num_unsuccessful_id']." max.) since ".date('Y/m/d H:i',$block_time)."</p>\n";
-				$blocked = True;
+				$acct_id = $GLOBALS['phpgw']->accounts->name2id($login);
+				$anon_users = array_flip($GLOBALS['phpgw']->acl->get_ids_for_location('anonymous',1,'phpgwapi'));
+				//echo "acct_id == $acct_id<br />anon_users<pre>" . print_r($anon_users, true) . '</pre>in_array == ' . intval( !is_array($anon_users) || !isset($anon_users[$acct_id]) );
+				if ( !is_array($anon_users) || !isset($anon_users[$acct_id]) )
+				{
+					//echo "<p>login_blocked: login='$login' ".$this->db->f(0)." tries (".$GLOBALS['phpgw_info']['server']['num_unsuccessful_id']." max.) since ".date('Y/m/d H:i',$block_time)."</p>\n";
+					$blocked = True;
+				}
 			}
+
 			if ($blocked && $GLOBALS['phpgw_info']['server']['admin_mails'] &&
-				// max. one mail each 5mins
-			    $GLOBALS['phpgw_info']['server']['login_blocked_mail_time'] < time()-5*60)
+				$GLOBALS['phpgw_info']['server']['login_blocked_mail_time'] < time()-5*60)// max. one mail each 5mins 
 			{
 				// notify admin(s) via email
 				$from    = 'phpGroupWare@'.$GLOBALS['phpgw_info']['server']['mail_suffix'];
