@@ -7,7 +7,7 @@
 	* @license http://www.fsf.org/licenses/lgpl.html GNU Lesser General Public License
 	* @package phpgwapi
 	* @subpackage utilities
-	* @version $Id: functions.inc.php,v 1.121.2.13.2.24 2005/08/26 01:33:15 skwashd Exp $
+	* @version $Id: functions.inc.php,v 1.121.2.13.2.32 2005/10/05 12:37:20 Caeies Exp $
 	*/
 
 	
@@ -42,34 +42,20 @@
 		return $value;
 	}
 
-	function clean_vars($vars)
+	function clean_vars($vars, $safe_redirect = True)
 	{
 		if ( !is_array($vars) )
 		{
-			$data_cleaner = createObject('phpgwapi.data_cleaner', $vars);
-			return $data_cleaner->clean();
+			return $GLOBALS['data_cleaner']->clean($vars, $safe_redirect);
 		}
 		
 		foreach ( $vars as $key => $val )
 		{
-			$vars[$key] = clean_vars($val);
+			$vars[$key] = clean_vars($val, $safe_redirect);
 		}
 		return $vars;
 	}
 
-	// Remove this and I will make sure that you lose important parts of your anatomy - skwashd
-	$GLOBALS['RAW_REQUEST'] = $_REQUEST; // if you really need the raw value
-	$to_cleans = array('_GET', '_POST', '_COOKIE', '_REQUEST');
-	foreach ( $to_cleans as $to_clean )
-	{
-		if ( isset($GLOBALS[$to_clean]) && is_array($GLOBALS[$to_clean]) && count($GLOBALS[$to_clean]) )
-		{
-			$GLOBALS['to_clean'] = clean_vars($GLOBALS['to_clean']);
-			$GLOBALS["HTTP{$to_change}_VARS"] = $GLOBALS[$to_change];//legacy app support - will be dropped in 18
-		}
-	}
-
-
 	/* Make sure the header.inc.php is current. */
 	if ($GLOBALS['phpgw_info']['server']['versions']['header'] < $GLOBALS['phpgw_info']['server']['versions']['current_header'])
 	{
@@ -221,12 +207,26 @@ my new logging stuff.  So I changed it.
 				$GLOBALS['phpgw']->db->query($cache_query,__LINE__,__FILE__);				
 			}
 			$cache_query = 'INSERT INTO phpgw_app_sessions(sessionid,loginid,app,location,content) VALUES('
-				. "'0','0','phpgwapi','config','".addslashes(serialize($GLOBALS['phpgw_info']['server']))."')";
+				. "'0','0','phpgwapi','config','". $GLOBALS['phpgw']->db->db_addslashes(serialize($GLOBALS['phpgw_info']['server']))."')";
 			$GLOBALS['phpgw']->db->query($cache_query,__LINE__,__FILE__);
 		}
 	}
 	unset($cache_query);
 	unset($server_info_cache);
+
+	// Remove this and I will make sure that you lose important parts of your anatomy - skwashd
+	$GLOBALS['RAW_REQUEST'] = $_REQUEST; // if you really need the raw value
+	$to_cleans = array('_GET', '_POST', '_COOKIE', '_REQUEST');
+	$GLOBALS['data_cleaner'] = createObject('phpgwapi.data_cleaner'); // We create it for the whole call ...
+	foreach ( $to_cleans as $to_clean )
+	{
+		if ( isset($GLOBALS[$to_clean]) && is_array($GLOBALS[$to_clean]) && count($GLOBALS[$to_clean]) )
+		{
+			$GLOBALS[$to_clean] = clean_vars($GLOBALS[$to_clean]);
+			$GLOBALS["HTTP{$to_clean}_VARS"] = $GLOBALS[$to_clean];//legacy app support - will be dropped in 18
+		}
+	}
+
 	if(@isset($GLOBALS['phpgw_info']['server']['enforce_ssl']) && !$HTTPS)
 	{
 		Header('Location: https://' . $GLOBALS['phpgw_info']['server']['hostname'] . $GLOBALS['phpgw_info']['server']['webserver_url'] . $_SERVER['REQUEST_URI']);
@@ -472,13 +472,18 @@ my new logging stuff.  So I changed it.
 		* Load the app include files if the exists                                *
 		\*************************************************************************/
 		/* Then the include file */
-		if (! preg_match ("/phpgwapi/i", PHPGW_APP_INC) && file_exists(PHPGW_APP_INC . '/functions.inc.php') && !isset($GLOBALS['phpgw_info']['menuaction']))
+		if ( PHPGW_APP_INC != '' 
+			&& strpos(PHPGW_APP_INC, 'phpgwapi') === false 
+			&& file_exists(PHPGW_APP_INC . '/functions.inc.php') 
+			&& !isset($GLOBALS['phpgw_info']['menuaction']))
 		{
 			include_once(PHPGW_APP_INC . '/functions.inc.php');
 		}
-		if (!@$GLOBALS['phpgw_info']['flags']['noheader'] && 
-			!@$GLOBALS['phpgw_info']['flags']['noappheader'] &&
-			file_exists(PHPGW_APP_INC . '/header.inc.php') && !isset($GLOBALS['phpgw_info']['menuaction']))
+		if ( !(isset($GLOBALS['phpgw_info']['flags']['noheader']) && $GLOBALS['phpgw_info']['flags']['noheader'])
+			&& !(isset($GLOBALS['phpgw_info']['flags']['noappheader']) && $GLOBALS['phpgw_info']['flags']['noappheader'])
+			&& PHPGW_APP_INC != ''
+			&& file_exists(PHPGW_APP_INC . '/header.inc.php') 
+			&& !isset($GLOBALS['phpgw_info']['menuaction']))
 		{
 			include_once(PHPGW_APP_INC . '/header.inc.php');
 		}
