@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_update.inc.php,v 1.53.2.9.2.44 2005/12/18 08:25:39 skwashd Exp $
+	// $Id: tables_update.inc.php,v 1.53.2.9.2.45 2006/08/31 11:08:41 skwashd Exp $
 	// $Source: /cvsroot/phpgwapi/phpgwapi/setup/tables_update.inc.php,v $
 
 	/* Include older phpGroupWare update support */
@@ -1808,4 +1808,10 @@
 	{
 		return $GLOBALS['phpgw_info']['phpgwapi']['currentver'] = '0.9.16.010';
 	}
+
+	$test[] = '0.9.16.010';
+	function phpgwapi_upgrade0_9_16_010()
+	{
+		return $GLOBALS['phpgw_info']['phpgwapi']['currentver'] = '0.9.16.011';
+	}
 ?>
