@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your   *
 	* option) any later version.                                               *
 	\**************************************************************************/
-	/* $Id: class.uicategories.inc.php,v 1.2.2.8.2.5 2004/12/21 21:53:39 ceb Exp $ */
+	/* $Id: class.uicategories.inc.php,v 1.2.2.8.2.6 2006/08/12 10:42:36 skwashd Exp $ */
 
 	class uicategories
 	{
@@ -486,8 +486,7 @@
 			$GLOBALS['phpgw']->template->set_var('category_list',$this->bo->cats->formated_list(array('type' => $type,'selected' => $cats[0]['parent'],
 																									'globals' => $global_cats, 'self' => $cat_id)));
 
-			$GLOBALS['phpgw']->template->set_var('access','<input type="checkbox" name="cat_access" value="True"'
-												. ($cats[0]['access'] == private ?' checked':'') . '>');
+			$GLOBALS['phpgw']->template->set_var('access','<input type="checkbox" name="cat_access" value="True"' . ($cats[0]['access'] == 'private' ? ' checked="checked"' : '') . '>');
 
 			if ($extra)
 			{
