@@ -10,13 +10,13 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: hook_deleteaccount.inc.php,v 1.1.2.2 2002/11/20 17:05:00 ralfbecker Exp $ */
+  /* $Id: hook_deleteaccount.inc.php,v 1.1.2.2.2.1 2005/12/04 04:45:02 skwashd Exp $ */
 
 	// Delete all records for a user
 	$table_locks = Array('phpgw_preferences');
 
 	$GLOBALS['phpgw']->db->lock($table_locks);
-	$GLOBALS['phpgw']->db->query('DELETE FROM phpgw_preferences WHERE preference_owner='.$GLOBALS['HTTP_POST_VARS']['account_id'],__LINE__,__FILE__);
+	$GLOBALS['phpgw']->db->query('DELETE FROM phpgw_preferences WHERE preference_owner = '. intval($_POST['account_id']), __LINE__, __FILE__);
 	$GLOBALS['phpgw']->db->unlock();
 
 
