@@ -23,7 +23,7 @@
 	* along with this program; if not, write to the Free Software       *
 	* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         *
 	\*******************************************************************/
-	/* $Id: class.boprojects.inc.php,v 1.42.2.5.2.39 2004/09/02 22:47:13 ceb Exp $ */
+	/* $Id: class.boprojects.inc.php,v 1.42.2.5.2.40 2005/05/23 23:13:46 ceb Exp $ */
 	// $Source: /cvsroot/phpgroupware/projects/inc/class.boprojects.inc.php,v $
 
 	class boprojects
@@ -387,7 +387,7 @@
 		function list_admins($action, $type, $start, $query, $sort, $order)
 		{
 			$admins = $this->read_admins($action, 'all');
-			$allaccounts = $GLOBALS['phpgw']->accounts->get_list($type, $start, $sort, $order, $query);
+			$allaccounts = $GLOBALS['phpgw']->accounts->get_list($type, -1, $sort, $order, $query);
 
 			$j = 0;
 			while (is_array($allaccounts) && list($null,$account) = each($allaccounts))
