@@ -1,17 +1,16 @@
 <?php
 	/**************************************************************************\
-	* phpGroupWare - Notes                                                     *
+	* phpGroupWare - QMailLDAP                                                 *
 	* http://www.phpgroupware.org                                              *
-	* Written by Bettina Gille [ceb@phpgroupware.org]                          *
 	* -----------------------------------------------                          *
 	*  This program is free software; you can redistribute it and/or modify it *
 	*  under the terms of the GNU General Public License as published by the   *
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php,v 1.1.1.1 2001/07/22 21:04:46 lkneschke Exp $ */
+	/* $Id: index.php,v 1.1.1.1.4.1 2005/02/28 17:21:16 ceb Exp $ */
 
-	$phpgw_info['flags'] = array
+	$GLOBALS['phpgw_info']['flags'] = array
 	(
 		'currentapp' => 'qmailldap',
 		'noheader'   => True,
@@ -19,6 +18,6 @@
 	);
 	include('../header.inc.php');
 
-	$obj = CreateObject('qmailldap.uiqmailldap');
-	$obj->listServers();
+	Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=qmailldap.uiqmailldap.listServers'));
+	$GLOBALS['phpgw']->common->phpgw_exit();
 ?>
