@@ -9,21 +9,21 @@
   *  Free Software Foundation; either version 2 of the License, or (at your  *
   *  option) any later version.                                              *
   \**************************************************************************/
-	/* $Id: hook_deleteaccount.inc.php,v 1.2 2001/11/28 03:42:56 milosch Exp $ */
+	/* $Id: hook_deleteaccount.inc.php,v 1.2.4.1 2005/12/04 04:45:02 skwashd Exp $ */
 	
 	// Delete all records for a user
 	$table_locks = Array('phpgw_todo');
 	$db2 = $GLOBALS['phpgw']->db;
 	$db2->lock($table_locks);
 
-	if(intval($GLOBALS['HTTP_POST_VARS']['new_owner'])==0)
+	if(intval($_POST['new_owner']) == 0)
 	{
-		$db2->query('DELETE FROM phpgw_todo WHERE todo_owner='.intval($GLOBALS['HTTP_POST_VARS']['account_id']),__LINE__,__FILE__);
+		$db2->query('DELETE FROM phpgw_todo WHERE todo_owner = ' . intval($_POST['account_id']),__LINE__,__FILE__);
 	}
 	else
 	{
-		$db2->query('UPDATE phpgw_todo SET todo_owner='.intval($GLOBALS['HTTP_POST_VARS']['new_owner'])
-			. ' WHERE todo_owner='.intval($GLOBALS['HTTP_POST_VARS']['account_id']),__LINE__,__FILE__);
+		$db2->query('UPDATE phpgw_todo SET todo_owner = '.intval($_POST['new_owner'])
+			. ' WHERE todo_owner = ' . intval($_POST['account_id']),__LINE__,__FILE__);
 	}
 	$db2->unlock();
 ?>
